@@ -397,27 +397,8 @@ void CtActions::link_clicked(const Glib::ustring& tag_property_value, bool from_
         _pCtMainWin->get_text_view().grab_focus();
         _pCtMainWin->get_text_view().get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
         _pCtMainWin->get_text_view().set_tooltip_text("");
-        if (!link_entry.anch.empty()) {
-            Glib::ustring anchor_name = link_entry.anch;
-            CtImageAnchor* imageAnchor = nullptr;
-            for (auto& widget : tree_iter.get_anchored_widgets_fast()) {
-                if (auto anchor = dynamic_cast<CtImageAnchor*>(widget)) {
-                    if (anchor->get_anchor_name() == anchor_name) {
-                        imageAnchor = anchor;
-                    }
-                }
-            }
-            if (not imageAnchor) {
-                if (anchor_name.size() > (size_t)CtConst::MAX_TOOLTIP_LINK_CHARS) {
-                    anchor_name = anchor_name.substr(0, (size_t)CtConst::MAX_TOOLTIP_LINK_CHARS) + "...";
-                }
-                CtDialogs::warning_dialog(str::format(_("No anchor named '%s' found"), str::xml_escape(anchor_name)), *_pCtMainWin);
-            }
-            else {
-                Gtk::TextIter iter_anchor = _curr_buffer()->get_iter_at_child_anchor(imageAnchor->getTextChildAnchor());
-                _curr_buffer()->place_cursor(iter_anchor);
-                _pCtMainWin->get_text_view().scroll_to(_curr_buffer()->get_insert(), CtTextView::TEXT_SCROLL_MARGIN);
-            }
+        if (not link_entry.anch.empty()) {
+            current_node_scroll_to_anchor(link_entry.anch);
         }
     }
     else {
@@ -425,6 +406,31 @@ void CtActions::link_clicked(const Glib::ustring& tag_property_value, bool from_
     }
 }
 
+void CtActions::current_node_scroll_to_anchor(Glib::ustring anchor_name)
+{
+    if (not _is_there_selected_node_or_error()) return;
+
+    CtImageAnchor* imageAnchor = nullptr;
+    for (auto& widget : _pCtMainWin->curr_tree_iter().get_anchored_widgets_fast()) {
+        if (auto anchor = dynamic_cast<CtImageAnchor*>(widget)) {
+            if (anchor->get_anchor_name() == anchor_name) {
+                imageAnchor = anchor;
+            }
+        }
+    }
+    if (not imageAnchor) {
+        if (anchor_name.size() > (size_t)CtConst::MAX_TOOLTIP_LINK_CHARS) {
+            anchor_name = anchor_name.substr(0, (size_t)CtConst::MAX_TOOLTIP_LINK_CHARS) + "...";
+        }
+        CtDialogs::warning_dialog(str::format(_("No anchor named '%s' found"), str::xml_escape(anchor_name)), *_pCtMainWin);
+    }
+    else {
+        Gtk::TextIter iter_anchor = _curr_buffer()->get_iter_at_child_anchor(imageAnchor->getTextChildAnchor());
+        _curr_buffer()->place_cursor(iter_anchor);
+        _pCtMainWin->get_text_view().scroll_to(_curr_buffer()->get_insert(), CtTextView::TEXT_SCROLL_MARGIN);
+    }
+}
+
 // Cut CodeBox
 void CtActions::codebox_cut()
 {
@@ -515,27 +521,24 @@ void CtActions::exec_code()
     binary_cmd = str::replace(binary_cmd, CtConst::CODE_EXEC_TMP_BIN, filepath_bin_tmp.string());
     Glib::ustring terminal_cmd = str::replace(code_exec_term, CtConst::CODE_EXEC_COMMAND, binary_cmd);
 
-    if (!CtDialogs::question_dialog(std::string("<b>")+_("Do you want to Execute the Code?")+"</b>", *_pCtMainWin)) {
+    if (_pCtConfig->codeExecConfirm and not CtDialogs::exec_code_confirm_dialog(*_pCtMainWin)) {
         return;
     }
-    g_file_set_contents(filepath_src_tmp.c_str(), code_val.c_str(), (gssize)code_val.bytes(), nullptr);
 
-    // if std::system is not enougth, then try g_spawn_async_with_pipes
-    int status = std::system(terminal_cmd.c_str());
-
-#ifdef _WIN32
-#define WEXITSTATUS(x) x
-#endif
-
-    // check exit code (0 - is good)
-    if (WEXITSTATUS(status) != 0) {
-        if (str::startswith(terminal_cmd, "xterm ")) {
-            status = std::system("xterm -version");
-            if (WEXITSTATUS(status) != 0) {
-                CtDialogs::error_dialog(_("Install the package 'xterm' or configure a different terminal in the Preferences Dialog"), *_pCtMainWin);
-            }
+#ifndef _WIN32
+    static bool xterm_verified{false};
+    if (not xterm_verified and str::startswith(terminal_cmd, "xterm ")) {
+        const int status = std::system("xterm -version");
+        if (WEXITSTATUS(status) != 0) {
+            CtDialogs::error_dialog(_("Install the package 'xterm' or configure a different terminal in the Preferences Dialog"), *_pCtMainWin);
+            return;
         }
+        xterm_verified = true;
     }
+#endif // !_WIN32
+
+    g_file_set_contents(filepath_src_tmp.c_str(), code_val.c_str(), (gssize)code_val.bytes(), nullptr);
+    (void)std::system(terminal_cmd.c_str());
 }
 
 // Load the CodeBox Content From a Text Fil
