@@ -511,7 +511,7 @@ bool CtTable::_on_key_press_event_cell(GdkEventKey* event)
             textView.grab_focus();
             return true;
         }
-        if (event->keyval == GDK_KEY_backslash) {
+        if (event->keyval == GDK_KEY_parenleft) {
             if (event->state & Gdk::MOD1_MASK) {
                 _pCtMainWin->get_ct_actions()->table_column_decrease_width();
             }
@@ -545,14 +545,16 @@ bool CtTable::_on_key_press_event_cell(GdkEventKey* event)
             _pCtMainWin->get_ct_actions()->table_column_right();
             return true;
         }
-        if (event->keyval == GDK_KEY_parenleft) {
-            if (rowIdx > 0) {
-                index = (rowIdx-1) * _tableMatrix.front().size() + colIdx;
+        if (event->keyval == GDK_KEY_backslash) {
+            if (event->state & Gdk::MOD1_MASK) {
+                if (rowIdx > 0) {
+                    index = (rowIdx-1) * _tableMatrix.front().size() + colIdx;
+                }
             }
-        }
-        else if (event->keyval == GDK_KEY_parenright) {
-            if (rowIdx+1 < _tableMatrix.size()) {
-                index = (rowIdx+1) * _tableMatrix.front().size() + colIdx;
+            else {
+                if ((rowIdx+1) < _tableMatrix.size()) {
+                    index = (rowIdx+1) * _tableMatrix.front().size() + colIdx;
+                }
             }
         }
     }
