@@ -81,6 +81,10 @@ CtTextView::CtTextView(CtMainWin* pCtMainWin)
                 break;
         }
     }, false);
+    signal_focus_out_event().connect([&](GdkEventFocus* /*gdk_event*/){
+        _columnEdit.column_mode_off();
+        return false; /*propagate event*/
+    }, false);
 }
 
 void CtTextView::setup_for_syntax(const std::string& syntax)
@@ -158,12 +162,10 @@ void CtTextView::list_change_level(Gtk::TextIter iter_insert, const CtListInfo&
     int next_level = level_increase ? curr_level+1 : curr_level-1;
     Gtk::TextIter iter_start = get_buffer()->get_iter_at_offset(curr_offset);
     CtListInfo prev_list_info = CtList{_pCtMainWin, get_buffer()}.get_prev_list_info_on_level(iter_start, next_level);
-    // print prev_list_info
     if (list_info.type != CtListType::Todo) {
         int bull_offset = curr_offset + 3*list_info.level;
         int bull_idx;
-        if (list_info.type == CtListType::Bullet)
-        {
+        if (list_info.type == CtListType::Bullet) {
             if (prev_list_info and prev_list_info.type == CtListType::Bullet) {
                 bull_idx = prev_list_info.num;
             }
@@ -171,6 +173,8 @@ void CtTextView::list_change_level(Gtk::TextIter iter_insert, const CtListInfo&
                 int idx_old = list_info.num;
                 int idx_offset = idx_old - curr_level % (int)_pCtConfig->charsListbul.size();
                 bull_idx = (next_level + idx_offset) % (int)_pCtConfig->charsListbul.size();
+                if (bull_idx < 0) bull_idx += _pCtConfig->charsListbul.size();
+                //spdlog::debug("idx_old={}, idx_offset={}, bull_idx={}", idx_old, idx_offset, bull_idx);
             }
             replace_text(_pCtConfig->charsListbul[(size_t)bull_idx], bull_offset, bull_offset+1);
         }
@@ -598,7 +602,6 @@ void CtTextView::cursor_and_tooltips_handler(int x, int y)
 
     if (_pCtMainWin->hovering_link_iter_offset() != hovering_link_iter_offset) {
         _pCtMainWin->hovering_link_iter_offset() = hovering_link_iter_offset;
-        // print "link", dad.hovering_link_iter_offset
     }
     if (_pCtMainWin->hovering_link_iter_offset() >= 0) {
         get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::HAND2));
@@ -608,11 +611,17 @@ void CtTextView::cursor_and_tooltips_handler(int x, int y)
         set_tooltip_text(tooltip);
     }
     else {
-        get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
-        set_tooltip_text("");
+        cursor_and_tooltips_reset();
     }
 }
 
+void CtTextView::cursor_and_tooltips_reset()
+{
+    _pCtMainWin->hovering_link_iter_offset() = -1;
+    get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
+    set_tooltip_text("");
+}
+
 // Increase or Decrease Text Font
 void CtTextView::zoom_text(const bool is_increase, const std::string& syntaxHighlighting)
 {
